@@ -35,5 +35,10 @@ DEBUG = setting_overrides.get(
 
 CACHE = setting_overrides.get(
     'CACHE',
-    not settings.DEBUG,
+    not DEBUG,
+)
+
+DEVTOOL = setting_overrides.get(
+    'DEVTOOL',
+    'eval-entry-map' if DEBUG else None,
 )
\ No newline at end of file
